pub struct VideoStreamInfo {
pub width: u32,
pub height: u32,
pub frame_rate: f64,
pub frames_count: u64,
}Fields
width: u32The width of each frame.
height: u32frame_rate: f64frames_count: u64The total count of frames in this stream as set in the metadata. The actual count of frames that can be read might differ.